@@ -1,6 +1,6 @@
 /* OpenVAS
  * $Id$
- * Description: Undocumented module.
+ * Description: Functions related to plugin cache and.
  *
  * Authors:
  * Renaud Deraison <deraison@nessus.org> (Original pre-fork development)
@@ -23,6 +23,33 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+/** @file
+ * OpenVAS-Server employs a plugin cache to avoid parsing all known nvts at
+ * start-up.
+ *
+ * The cache consists of a .desc file for each script (e.g. cache file of
+ * nvts/xyz.nasl is nvts/xyz.nas.desc), which contains a memory dump of the
+ * corresponding plugin struct.
+ *
+ * The cache is used as followed:
+ *
+ * 1. Init the store with store_init.
+ *
+ * 2. Add nvts by calling store_plugin or
+ *
+ * 3. Give the store a file path (store_load_plugin)
+ * and receive the plugin as arglist. Under nice conditions the information
+ * contained in the cache file can be used. Under not so nice conditions, the
+ * store returns NULL (cache is either outdated, contains error or an error
+ * occurred).
+ *
+ * The store is updated at each openvasd start up. There the plugin loader
+ * iterates over plugin files and tries to retrieve the cached version.
+ * If there is no cached version (or @ref store_load_plugin returns Null for
+ * another reason, e.g.because  the script file seems to have been modified in
+ * between) the plugin is added to the store (@ref store_plugin).
+ */
+
 #include <string.h>
 #include <stdio.h>
 #include <sys/stat.h>
@@ -43,19 +70,18 @@
 #include "plugutils_internal.h"
 
 /*-----------------------------------------------------------------------------*/
-static char * arglist2str(struct arglist * arg)
+static char *
+arglist2str(struct arglist * arg)
 {
  char * ret;
  int sz;
- 
- 
- 
+
  if(arg == NULL)
   return estrdup("");
- 
+
  if(arg->name == NULL)
   return estrdup("");
-  
+
  sz = (strlen(arg->name) + 1) * 10;
  ret = emalloc(sz);
  strncpy(ret, arg->name, sz - 1);
@@ -64,14 +90,14 @@ static char * arglist2str(struct arglist * arg)
   return ret;
 
  while(arg->next != NULL)
- { 
+ {
    if(arg->name == NULL)
      return ret;
    if(strlen(arg->name) + 3 + strlen(ret) >= sz )
-   {
-    sz = strlen(arg->name) + 3 + strlen(ret) * 2;
-    ret = erealloc(ret, sz);
-   }
+    {
+      sz = strlen(arg->name) + 3 + strlen(ret) * 2;
+      ret = erealloc(ret, sz);
+    }
    strncat(ret, ", ", sz - 1); /* RATS: ignore */
    strncat(ret, arg->name, sz - 1); /* RATS: ignore */ 
    arg = arg->next;
@@ -92,8 +118,7 @@ struct arglist * str2arglist(char * str)
   }
 
  ret = emalloc ( sizeof(struct arglist) );
-  
-  
+
  while((t = strchr(str, ',')) != NULL)
  {
   t[0] = 0;
@@ -108,41 +133,50 @@ struct arglist * str2arglist(char * str)
  while(str[0]==' ')str++;
  if(str[0] != '\0')
    arg_add_value(ret, str, ARG_INT, 0, (void*)1);
-  
 
   return ret;
 }
 
 
 /**
- * Copies content of one string into the other.
+ * @brief Copies content of one string into the other.
+ *
  * Does not check nul-termination.
+ * If it fails, an error message containing the name of the NVT and the
+ * description of the failed property will be printed to stderr.
+ *
  * @param str Source string, might be NULL.
  * @param dst Destination string.
  * @param sz max number of bytes to copy into dst.
- * @param path Filename path for error message (!?).
- * @param item Description of what had to be copied for error message (!?).
+ * @param filename Filename of the NVT, used in the error message.
+ * @param item Description of the property to be copied, used in the error
+ * message.
+ *
  * @return 0 on success, -1 otherwise.
  */
-static int safe_copy(char * str, char * dst, int sz, char * path, char * item)
+static int
+safe_copy (char * str, char * dst, int sz, char * filename, char * item)
 {
- if(str == NULL)	/* empty strings are OK */
+ if (str == NULL) /* empty strings are OK */
   {
-  dst[0] = '\0';
-  return 0;
+    dst[0] = '\0';
+    return 0;
   }
-  
- if(strlen(str) >= sz)
- {
-  fprintf(stderr, "openvas-libraries/libopenvas/store.c: %s has a too long %s (%ld)\n", path, item, (long)strlen(str));
-  return -1;
- }
- strcpy(dst, str); /* RATS: ignore */
+
+ if (strlen(str) >= sz)
+  {
+    fprintf(stderr, "\r%s: The length of the value for the property \"%s\" exceeds the allowed maximum length (is %ld characters, maximum length is %d).\n", filename, item, (long) strlen (str), sz);
+    return -1;
+  }
+
+ strcpy (dst, str); /* RATS: ignore */
  return 0;
 }
 
-/*
- * store_dir holds the directory name for the cache. If run with older
+/**
+ * @brief Holds the directory name for the cache.
+ * 
+ * If run with older
  * installations of OpenVAS (<=2.0.0), then it is initialized with
  * the NVT directory (server preference "plugins_folder")
  * and appends "/.desc/". For newer versions it is the directory
@@ -162,7 +196,8 @@ static char store_dir[MAXPATHLEN+1] = "";
  *            In any other case than 0 @ref store_dir is
  *            not set and a error is printed to stderr
  */
-int store_init(char * dir)
+int
+store_init (const char * dir)
 {
   struct stat st;
   int i = 0;
@@ -172,7 +207,8 @@ int store_init(char * dir)
     return -3;
   }
 
-  for (;i < sizeof(store_dir) && dir[i];i ++) ;
+  for (;i < sizeof(store_dir) && dir[i];i ++)
+    ;
   if (i == sizeof(store_dir)) {
     fprintf(stderr,
             "store_init(): path too long with more than %d characters\n", i);
@@ -184,7 +220,7 @@ int store_init(char * dir)
     return -2;
   }
 
-  strncpy(store_dir, dir, sizeof(store_dir));
+  strncpy (store_dir, dir, sizeof(store_dir));
 
   return 0;
 }
@@ -195,8 +231,11 @@ int store_init(char * dir)
  * Don't use this method anymore. It is here only for legacy to be compatible with
  * openvas-server <= 2.0.0.
  * The new method to use is @ref store_init .
+ *
+ * @return Always 0.
  */
-int store_init_sys(char * dir)
+int
+store_init_sys (char * dir)
 {
  snprintf(store_dir, sizeof(store_dir), "%s/.desc", dir); /* RATS: ignore */
  if((mkdir(store_dir, 0755) < 0) && (errno != EEXIST))
@@ -204,7 +243,7 @@ int store_init_sys(char * dir)
   fprintf(stderr, "mkdir(%s) : %s\n", store_dir, strerror(errno));
   return -1;
  }
- 
+
  return 0;
 }
 
@@ -234,34 +273,35 @@ int store_init_user(char * dir)
 
  * @return -1 upon failure, 0 for success.
  */
-static int store_get_plugin_f(struct plugin * plugin, struct pprefs * pprefs,
-  gchar * desc_file)
+static int
+store_get_plugin_f (struct plugin * plugin, struct pprefs * pprefs,
+                    gchar * desc_file)
 {
  int fd;
  struct plugin * p;
  struct stat st;
  int len;
- 
+
  bzero(plugin, sizeof(*plugin));
  plugin->id = -1;
- 
+
   if(desc_file == NULL || desc_file[0] == '\0')
     return -1;
 
  fd = open(desc_file, O_RDONLY);
  if(fd < 0)
   return -1;
- 
+
  if(fstat(fd, &st) < 0)
- { 
+ {
   perror("fstat ");
-  close(fd);
+  close (fd);
   return -1;
- } 
+ }
  
  if(st.st_size == 0)
  {
-  close(fd);
+  close (fd);
   return 0;
  }
  
@@ -270,20 +310,18 @@ static int store_get_plugin_f(struct plugin * plugin, struct pprefs * pprefs,
  if(p == MAP_FAILED || p == NULL)
  {
   perror("mmap ");
-  close(fd);
+  close (fd);
   return -1;
  }
 
- 
  bcopy(p, plugin, sizeof(struct plugin));
 
- 
  if(p->has_prefs && pprefs != NULL)
  {
   bcopy((char*)p + sizeof(struct plugin), pprefs, sizeof(struct pprefs) * MAX_PREFS);
  }
  munmap((char*)p, len);
- close(fd);
+ close (fd);
  return 0;
 }
 
@@ -305,148 +343,158 @@ int store_get_plugin(struct plugin * p, char * desc_file)
  * @param prefs Plugin preference arglist.
  *
  * NULL is returned in either of these cases:
- * 1) the .desc does not exist
- * 2) Nvt definition file (e.g. xyz.nasl) or nvt signature (xyz.asc) file is
- *       newer than the .desc file
- * 3) the magic number test failed (other file format expected).
- * 4) an internal error occured.
+ * 1) The .NVT definition or .desc file does not exist.
+ * 2) NVT definition file (e.g. xyz.nasl) or nvt signature (xyz.asc) file is
+ *    newer than the .desc file.
+ * 3) The NVT definition files (e.g. xyz.nasl) or nvt signature (xyz.asc) files
+ *    timestamp is in the future.
+ * 4) The magic number test failed (other file format expected).
+ * 5) An internal error occured.
+ *
+ * Point 4) is necessary because the cache will not create .desc files with
+ * timestamps in the future. Thus, when creating a new cache file for the given
+ * NVT, it would not be able to become loaded from the cache (point 2)).
  *
  * @return Pointer to plugin as arglist or NULL.
  */
-struct arglist * store_load_plugin(char * dir, char * file,
-  struct arglist * prefs)
+struct arglist *
+store_load_plugin (const char * dir, const char * file, struct arglist * prefs)
 {
-  gchar * dummy = g_build_filename(store_dir, file, NULL);
-  gchar * desc_file = g_strconcat(dummy, ".desc", NULL);
-  gchar * plug_file = g_build_filename(dir, file, NULL);
-  gchar * asc_file = g_strconcat(dummy, ".asc", NULL);
- struct plugin p;
- struct pprefs pp[MAX_PREFS];
- 
- struct arglist * ret;
- int i;
- struct stat stat_plug,
-        stat_desc,
-        stat_asc;
- struct arglist * al;
- 
-  g_free(dummy);
+  gchar * plug_file = g_build_filename (dir, file, NULL);
+  gchar * asc_file  = g_strconcat (plug_file, ".asc", NULL);
+  gchar * dummy     = g_build_filename (store_dir, file, NULL);
+  gchar * desc_file = g_strconcat (dummy, ".desc", NULL);
 
-  if (desc_file == NULL || asc_file == NULL || plug_file == NULL) {
-    g_free(desc_file);
-    g_free(asc_file);
-    g_free(plug_file);
-    return NULL; // g_build_filename failed
-  }
+  struct plugin p;
+  struct pprefs pp[MAX_PREFS];
 
- bzero(pp, sizeof(pp));
+  struct arglist * ret;
+  struct arglist * al;
 
- /* Plugin and cache file have to exist */
- if (  stat(plug_file, &stat_plug) < 0 || stat(desc_file, &stat_desc) < 0) {
-   g_free(desc_file);
-   g_free(asc_file);
-   g_free(plug_file);
-   return NULL;
- }
+  struct stat stat_plug;
+  struct stat stat_desc;
+  struct stat stat_asc;
 
- /* 
-  * Look if the plugin (.nasl/.oval etc) or the signature (.asc) is newer than
-  * the description (.desc). If that's the case also make sure that
-  * the plugin and signatures mtime is not in the future...
-  */
- if( stat_plug.st_mtime > stat_desc.st_mtime 
-    && stat_asc.st_mtime  > stat_desc.st_mtime ) {
-   g_free(desc_file);
-   g_free(asc_file);
-   g_free(plug_file);
-   return NULL;
- }
+  int i;
 
- /* 
-  * Look if a signature file (.asc) exists. If so and it is newer than
-  * the description (.desc) (and the mtime is not in the future), return NULL.
-  */ 
- if(    stat(asc_file, &stat_asc) 
-     && stat_asc.st_mtime > stat_desc.st_mtime 
-     && stat_asc.st_mtime <= time(NULL) ) {
-    g_free(desc_file);
-    g_free(asc_file);
-    g_free(plug_file);
-    return NULL;
-  }
+  g_free (dummy);
 
-  if((store_get_plugin_f(&p, pp, desc_file) < 0) ||
-     (p.magic != MAGIC) ||
-     (p.oid == NULL)) {
-    g_free(desc_file);
-    g_free(asc_file);
-    g_free(plug_file);
-    return NULL;
-  }
+  if (desc_file == NULL || asc_file == NULL || plug_file == NULL)
+    {
+      g_free (desc_file);
+      g_free (asc_file);
+      g_free (plug_file);
+      return NULL; // g_build_filename failed
+    }
 
- ret = emalloc(sizeof(struct arglist));   
- plug_set_oid(ret, p.oid);
- plug_set_category(ret, p.category);
- plug_set_cachefile(ret, desc_file);
- plug_set_path(ret, p.path);
- plug_set_family(ret, p.family, NULL);
- plug_set_sign_key_ids(ret, p.sign_key_ids);
+  bzero (pp, sizeof(pp));
 
-  al = str2arglist(p.required_ports);
- if ( al != NULL ) arg_add_value(ret, "required_ports", ARG_ARGLIST, -1, al);
+  /* Plugin and cache file have to exist */
+  if (stat(plug_file, &stat_plug) < 0 || stat(desc_file, &stat_desc) < 0)
+    {
+      g_free (desc_file);
+      g_free (asc_file);
+      g_free (plug_file);
+      return NULL;
+    }
 
- al = str2arglist(p.required_keys);
- if ( al != NULL ) arg_add_value(ret, "required_keys", ARG_ARGLIST, -1, al);
+   /* Look if the plugin (.nasl/.oval etc) is newer than the description
+    * (.desc). If that's the case also make sure that the plugins mtime is not
+    * in the future...  */
+   if (   stat_plug.st_mtime > stat_desc.st_mtime
+       && stat_asc.st_mtime  <= time (NULL))
+    {
+      g_free (desc_file);
+      g_free (asc_file);
+      g_free (plug_file);
+      return NULL;
+    }
 
- al = str2arglist(p.required_udp_ports);
- if ( al != NULL ) arg_add_value(ret, "required_udp_ports", ARG_ARGLIST, -1, al)
-;
+  /* Look if a signature file (.asc) exists. If so and it is newer than
+   * the description (.desc) (and the mtime is not in the future), return NULL.  */
+  if (   stat (asc_file, &stat_asc) == 0
+      && stat_asc.st_mtime > stat_desc.st_mtime
+      && stat_asc.st_mtime <= time (NULL) )
+    {
+      g_free (desc_file);
+      g_free (asc_file);
+      g_free (plug_file);
+      return NULL;
+    }
 
- al = str2arglist(p.excluded_keys);
- if ( al != NULL ) arg_add_value(ret, "excluded_keys", ARG_ARGLIST, -1, al);
+  if ((store_get_plugin_f(&p, pp, desc_file) < 0) ||
+      (p.magic != MAGIC) ||
+      (p.oid == NULL))
+    {
+      g_free (desc_file);
+      g_free (asc_file);
+      g_free (plug_file);
+      return NULL;
+    }
 
- al = str2arglist(p.dependencies);
- if ( al != NULL ) arg_add_value(ret, "DEPENDENCIES", ARG_ARGLIST, -1, al);
+  ret = emalloc (sizeof(struct arglist));
+  plug_set_oid (ret, p.oid);
+  plug_set_category (ret, p.category);
+  plug_set_cachefile (ret, desc_file);
+  plug_set_path (ret, p.path);
+  plug_set_family (ret, p.family, NULL);
+  plug_set_sign_key_ids (ret, p.sign_key_ids);
 
- 
- if ( p.timeout != 0 ) arg_add_value(ret, "TIMEOUT", ARG_INT, -1, GSIZE_TO_POINTER(p.timeout));
+  al = str2arglist (p.required_ports);
+  if (al != NULL) arg_add_value (ret, "required_ports", ARG_ARGLIST, -1, al);
 
- arg_add_value(ret, "NAME", ARG_STRING, strlen(p.name), estrdup(p.name));
+  al = str2arglist (p.required_keys);
+  if (al != NULL) arg_add_value (ret, "required_keys", ARG_ARGLIST, -1, al);
 
+  al = str2arglist (p.mandatory_keys);
+  if (al != NULL) arg_add_value (ret, "mandatory_keys", ARG_ARGLIST, -1, al);
 
- arg_add_value(ret, "preferences", ARG_ARGLIST, -1, prefs);
- 
- if(p.has_prefs)
- {
- for(i=0;pp[i].type[0] != '\0';i++)
-  { 
-   _add_plugin_preference(prefs, p.name, pp[i].name, pp[i].type, pp[i].dfl);
-  }
- }
+  al = str2arglist (p.required_udp_ports);
+  if (al != NULL) arg_add_value (ret, "required_udp_ports", ARG_ARGLIST, -1, al);
 
-  g_free(desc_file);
-  g_free(asc_file);
-  g_free(plug_file);
+  al = str2arglist (p.excluded_keys);
+  if (al != NULL) arg_add_value (ret, "excluded_keys", ARG_ARGLIST, -1, al);
 
- return ret;
+  al = str2arglist (p.dependencies);
+  if (al != NULL) arg_add_value (ret, "DEPENDENCIES", ARG_ARGLIST, -1, al);
+
+  if (p.timeout != 0) arg_add_value (ret, "TIMEOUT", ARG_INT, -1, GSIZE_TO_POINTER(p.timeout));
+
+  arg_add_value (ret, "NAME", ARG_STRING, strlen(p.name), estrdup(p.name));
+
+  arg_add_value (ret, "preferences", ARG_ARGLIST, -1, prefs);
+
+  if (p.has_prefs)
+    {
+      for (i=0; pp[i].type[0] != '\0'; i++)
+        {
+         _add_plugin_preference (prefs, p.name, pp[i].name, pp[i].type, pp[i].dfl);
+        }
+    }
+
+  g_free (desc_file);
+  g_free (asc_file);
+  g_free (plug_file);
+
+  return ret;
 }
 
 /**
- * @brief Creates a entry in the store for data of "plugin" into cache file "file"
- * which is placed in the cache directory.
+ * @brief Creates an entry in the store for data of "plugin" into cache file
+ * @brief "file" which is placed in the cache directory.
  *
  * @param plugin    Data structure that contains a plugin description
  * @param file      Name of corresponding plugin file (e.g. "x.nasl", "x.nes"
  *                  or "x.oval". It can also be something like
  *                  "subdir1/subdir2/scriptname.nasl").
  */
-void store_plugin(struct arglist * plugin, char * file)
+void
+store_plugin (struct arglist * plugin, char * file)
 {
-  gchar * dummy = g_build_filename(store_dir, file, NULL);
-  gchar * desc_file = g_strconcat(dummy, ".desc", NULL);
+  gchar * dummy = g_build_filename (store_dir, file, NULL);
+  gchar * desc_file = g_strconcat (dummy, ".desc", NULL);
   // assume there is a ".desc" at the end in the store_dir path
-  // in order to guess the path of the actual plugin:
-  gchar * path = g_build_filename(store_dir, "..", file, NULL);
+  gchar * path = g_strdup (file);
  struct plugin plug;
  struct pprefs pp[MAX_PREFS+1];
  char  * str;
@@ -472,15 +520,13 @@ void store_plugin(struct arglist * plugin, char * file)
  e = safe_copy(str, plug.oid, sizeof(plug.oid), path, "oid");
  if(e < 0) return;
 
- 
  plug.timeout = plug_get_timeout(plugin);
  plug.category = plug_get_category(plugin);
- 
+
  str = plug_get_name(plugin);
  e = safe_copy(str, plug.name, sizeof(plug.name), path, "name");
  if(e < 0) return;
  
- 
  str = _plug_get_version(plugin);
  e = safe_copy(str, plug.version, sizeof(plug.version), path, "version");
  if(e < 0) return;
@@ -499,7 +545,7 @@ void store_plugin(struct arglist * plugin, char * file)
  if(e < 0) return;
  
  str = _plug_get_family(plugin);
- e = safe_copy(str, plug.family, sizeof(plug.family), path, "family");
+ e = safe_copy (str, plug.family, sizeof(plug.family), path, "family");
  if(e < 0) return;
  
  str = _plug_get_cve_id(plugin);
@@ -531,6 +577,12 @@ void store_plugin(struct arglist * plugin, char * file)
  efree(&str);
  if(e < 0) return;
  
+ arglist = plug_get_mandatory_keys(plugin);
+ str = arglist2str(arglist);
+ e = safe_copy(str, plug.mandatory_keys, sizeof(plug.mandatory_keys), path, "mandatory keys");
+ efree(&str);
+ if(e < 0) return;
+ 
  arglist = plug_get_excluded_keys(plugin);
  str = arglist2str(arglist);
  e = safe_copy(str, plug.excluded_keys, sizeof(plug.excluded_keys), path, "excluded_keys");
@@ -561,13 +613,13 @@ void store_plugin(struct arglist * plugin, char * file)
  if( arglist != NULL )
  {
   char * p_name = plug_get_name(plugin);
-  
+
   while(arglist->next != NULL)
   {
    char * name = arglist->name;
    char * dfl = arglist->value;
    char * type, * str;
-   
+
    type = arglist->name;
    str = strchr(type, '/');
    str[0] = '\0';
@@ -579,8 +631,7 @@ void store_plugin(struct arglist * plugin, char * file)
    e = safe_copy(dfl, pp[num_plugin_prefs].dfl, sizeof(pp[num_plugin_prefs].dfl), path, "preference-default");
    if(e < 0) return;
    num_plugin_prefs ++;
-  
-   
+
    if(num_plugin_prefs >= MAX_PREFS)
    {
     fprintf(stderr, "%s: too many preferences\n", path);
@@ -592,7 +643,7 @@ void store_plugin(struct arglist * plugin, char * file)
   }
  }
  
- if(num_plugin_prefs > 0)
+ if (num_plugin_prefs > 0)
   plug.has_prefs = 1;
  
  fd = open(desc_file, O_RDWR|O_CREAT|O_TRUNC, 0644);
@@ -613,7 +664,7 @@ void store_plugin(struct arglist * plugin, char * file)
  
   if(num_plugin_prefs > 0)
     write(fd, pp, sizeof(pp));
-  close(fd); 
+  close (fd);
  
  arg_set_value(plugin, "preferences", -1, NULL);
  arg_free_all(plugin);
@@ -625,13 +676,14 @@ void store_plugin(struct arglist * plugin, char * file)
 /*---------------------------------------------------------------------*/
 
 
-char * store_fetch_path(struct arglist * desc)
+char *
+store_fetch_path (struct arglist * desc)
 {
- char * fname = plug_get_cachefile(desc);
- static struct plugin p;
- 
- store_get_plugin(&p, fname);
- return p.path;
+  char * fname = plug_get_cachefile (desc);
+  static struct plugin p;
+
+  store_get_plugin (&p, fname);
+  return p.path;
 }
 
 char * store_fetch_version(struct arglist * desc)
@@ -735,10 +787,21 @@ struct arglist * store_fetch_required_keys(struct arglist * desc)
  char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  struct arglist * ret;
- 
+
  store_get_plugin(&p, fname);
  ret = str2arglist(p.required_keys);
- return ret; 
+ return ret;
+}
+
+struct arglist * store_fetch_mandatory_keys(struct arglist * desc)
+{
+ char * fname = plug_get_cachefile(desc);
+ static struct plugin p;
+ struct arglist * ret;
+
+ store_get_plugin(&p, fname);
+ ret = str2arglist(p.mandatory_keys);
+ return ret;
 }
 
 struct arglist * store_fetch_excluded_keys(struct arglist * desc)
@@ -746,63 +809,30 @@ struct arglist * store_fetch_excluded_keys(struct arglist * desc)
  char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  struct arglist * ret;
- 
+
  store_get_plugin(&p, fname);
  ret = str2arglist(p.excluded_keys);
- return ret; 
+ return ret;
 }
 
 struct arglist * store_fetch_required_ports(struct arglist * desc)
 {
- char * fname = plug_get_cachefile(desc);
+ char * fname = plug_get_cachefile (desc);
  static struct plugin p;
  struct arglist * ret;
- 
- store_get_plugin(&p, fname);
- ret = str2arglist(p.required_ports);
- return ret; 
+
+ store_get_plugin (&p, fname);
+ ret = str2arglist (p.required_ports);
+ return ret;
 }
 
-struct arglist * store_fetch_required_udp_ports(struct arglist * desc)
+struct arglist *
+store_fetch_required_udp_ports (struct arglist * desc)
 {
- char * fname = plug_get_cachefile(desc);
- static struct plugin p;
- struct arglist * ret;
- 
- store_get_plugin(&p, fname);
- ret = str2arglist(p.required_udp_ports);
- return ret; 
+  char * fname = plug_get_cachefile (desc);
+  static struct plugin p;
+  struct arglist * ret;
+  store_get_plugin (&p, fname);
+  ret = str2arglist (p.required_udp_ports);
+  return ret;
 }
-
-
- 
-/*---------------------------------------------------------------------*/
-
-#if 0
-void store_dump_plugin(int id)
-{
- struct plugin plugin;
- store_get_plugin(&plugin, id);
- 
- printf("PLUGIN ID# %d\n", plugin.id);
- printf("in %s\n", plugin.path);
- printf("\n\n");
- printf("Name: %s\n", plugin.name);
- printf("timeout : %d\n", plugin.timeout);
- printf("category: %d\n",  plugin.category);
- printf("version : %s\n",  plugin.version);
- printf("summary : %s\n",  plugin.summary);
- printf("description: %s\n",  plugin.description);
- printf("copyright: %s\n",  plugin.copyright);
- printf("family %s\n",  plugin.family);
- printf("cve_id : %s\n",  plugin.cve_id);
- printf("bid : %s\n",  plugin.bid);
- printf("xrefs : %s\n",  plugin.xrefs);
- printf("tags : %s\n",  plugin.tags);
- printf("dependencies: %s\n", plugin.dependencies);
- printf("required_keys : %s\n", plugin.required_keys);
- printf("excluded_key : %s\n", plugin.excluded_keys);
- printf("required_ports: %s\n", plugin.required_ports);
- printf("required_udp_ports: %s\n", plugin.required_udp_ports);
-}
-#endif
