@@ -26,9 +26,12 @@
 #ifndef OPENVAS_STORE_H
 #define OPENVAS_STORE_H
 
-struct arglist * store_plugin(struct arglist *,  char *);
+void store_plugin(struct arglist *,  char *);
 struct arglist * store_load_plugin(char *, char *,  struct arglist*);
-int store_init_sys(char *);
-int store_init_user(char *);
+int store_init(char *);
+
+/* These can be removed with the next major release after 2.0: */
+__attribute__ ((__deprecated__)) int store_init_sys(char *);
+__attribute__ ((__deprecated__)) int store_init_user(char *);
 
 #endif
